# -*- coding: utf-8 -*-
"""
AMD_Tools3の関数「GetCSV_Map」の利用法を理解するためのサンプルプログラム

GetCSV_Mapは気象データをOPeNDAPサーバーまたはローカルファイルから取得する関数です。
　配列の列数は、取り込み範囲の先頭行で判別する。行数は、EOFまでの行数から判別
する。文字列「nan」は、numpy.nanとして理解される。これ以外の文字列が検出される
と警告文を表示し、nanを返す。
書式
    GetCSV_Map(filename, skiprow=0,upsidedown=True)
引数(必須)：
    filename：読み込むべきCSVファイルの名前。
引数(必要に応じ使用)：
    skiprow：余白や見出しなどに使用されていて読み込み対象としない行の数。
            指定を省略した場合は0に設定され、すべての行が読み込み対象となる。
    upsidedown：この関数は読み込んだ後、行の順序を転置する。行わないときは
            「upsidedown=False」と指定する。
戻り値：
    numpyの浮動小数点配列。数値以外には無効値(nan)が与えられる。

　このサンプルプログラムでは、下のような内容のcsvファイルを読み込んでこの関数の利用法を説明します。
 ------------------------------
"A列","B列","C列","D列","E列"
nan,1.0 ,0.5 ,3.0 ,4.5
1.0 ,0.0 ,0.0 ,0.0 ,0.0 
2.0 ,"3.5",nan,0.0 ,0.0 
9.9 ,9.9 ,9.9 ,9.9 ,9.9 
 ------------------------------
　このサンプルプログラムを実行するには、Python統合開発環境Spyderのエディタペインにプログラムファイル
 を読み込んでから実行ボタン(三角ボタン）をクリックしてください。

Hiroyuki OHNO, 2017.02.08
"""
import AMD_Tools3 as AMD

filename = "sample_GetCSV_Map-data.csv"
Msh = AMD.GetCSV_Map(filename)
print(Msh)
print()
"""
　オプション無しで読み込むと、下のような表示となります。
　警告が2件表示されています。まず、見出しの文字が数値でないため無効値に置き換えられました。さらに、
4行目の"3.5"についても数値でないと判断され無効値に置き換えられました。
　GetCSV_Mapは、読み込んだCSVファイルの行を逆順に入れ替えて取り込みます。これは、メッシュ農業気象
 データが、南から北にデータを格納しているのに対し、外部の地理データの多くは北を上、すなわち、
 北から南にデータを格納しているからです。
 
Warning: possibly illegal elements
Row 1: "A列","B列","C列","D列","E列"

Warning: possibly illegal elements
Row 4: 2.0 ,"3.5",nan,0.0 ,0.0 

sample03_GetCSV_Map_data.csv:  (5, 5)
[[ 9.89999962  9.89999962  9.89999962  9.89999962  9.89999962]
 [ 2.                 nan         nan  0.          0.        ]
 [ 1.          0.          0.          0.          0.        ]
 [        nan  1.          0.5         3.          4.5       ]
 [        nan         nan         nan         nan         nan]]
"""


Msh = AMD.GetCSV_Map(filename,skiprow=1,upsidedown=False)
print(Msh)
"""
　見出し行を無視するには、オプション引数skiprownに無視する行数を与えます。
　南北の転置をさせなくするには、オプション引数upsidedownに偽(Falseまたは0)を与えます。

Warning: possibly illegal elements
Row 4: 2.0 ,"3.5",nan,0.0 ,0.0 

sample03_GetCSV_Map_data.csv:  (4, 5)
[[        nan  1.          0.5         3.          4.5       ]
 [ 1.          0.          0.          0.          0.        ]
 [ 2.                 nan         nan  0.          0.        ]
 [ 9.89999962  9.89999962  9.89999962  9.89999962  9.89999962]]
"""
