# -*- coding: utf-8 -*-
"""
AMD_Tools3の関数「PutCSV_TS」の利用法を理解するためのサンプルプログラム

PutCSV_TSは、時系列のデータをCSV形式のファイルで出力する関数です。
書式：
    PutCSV_TS(Var, tim, header=None, filename='result.csv')
引数(必須)：
     Var：時系列のデータ。1次元である必要は必ずしも無い。第1番目の添え字が列、
         第二番目の添え字が行として並ぶ。従って2系列の1年分の日別データは、
         Var.shape=(2,365,)でなければならない。二つの1次元配列V1、V2からこの
         ような配列を簡単に作成するには「Ver=np.array([V1,V2])」とするとよい。
     tim：時刻の見出しとして使用される一次元配列。第1列に行方向に出力される。
         で並ぶ。element：気象要素記号で、'TMP_mea'などの文字列で与える
引数(必要に応じ指定)：
     header：引数に「header='moji,retsu'」として文字列を与えると、出力ファイルの
         第1行目にこの文字列が出力される。
     filename：引数に「filename='fairun_no_namae.csv'」として文字列を与えると、
         ファイルがこの名前で出力される。これを指定しない場合は、デフォルトの
         ファイル名「result.csv」が用いられる。


　このサンプルプログラムでは、メッシュ農業気象データ配信サーバーから取得した特定地点の
気象データの日別値を、データが行方向に並ぶcsvファイルとして書き出す方法を説明します。

　このサンプルプログラムを実行するには、Python統合開発環境Spyderのエディタペインにプログラムファイル
 を読み込んでから実行ボタン(三角ボタン）をクリックしてください。

Hiroyuki OHNO, 2017.02.08
"""
import AMD_Tools3 as AMD
import numpy as np


# 取得する気象データの設定
element = 'TMP_mea'                         #気象要素の指定。TMP_meaは日平均気温を意味します。
timedomain = [ "2016-04-01", "2016-04-14" ] #期間の設定。
lalodomain = [ 36.0566, 36.0566, 140.125, 140.125]  #茨城県つくば市「つくば(舘野)」

# 気象データの取得
Msh,tim,lat,lon = AMD.GetMetData(element,timedomain,lalodomain)
Msh = Msh[:,0,0]     #入れ物の入れ替え(3次元から1次元へ)

AMD.PutCSV_TS(Msh, tim, header="日付,気温")
"""
上の文を実行するとresult.csvというファイルが作成され、下のような内容が書き込まれます。
----------------------
日付	気温
2016/4/1 0:00,11.76
2016/4/2 0:00,10.4662
2016/4/3 0:00,13.4721
2016/4/4 0:00,14.3774
2016/4/5 0:00,9.78284
2016/4/6 0:00,12.6873
2016/4/7 0:00,12.2915
2016/4/8 0:00,13.3953
2016/4/9 0:00,15.498
2016/4/10 0:00,14.5004
2016/4/11 0:00,10.7019
2016/4/12 0:00,8.80379
2016/4/13 0:00,14.2047
2016/4/14 0:00,14.7056
----------------------
"""

MshN,tim,lat,lon = AMD.GetMetData(element,timedomain,lalodomain,cli=1)
MshN = MshN[:,0,0]   #入れ物の入れ替え(3次元から1次元へ)
"""
 気温の観測値だけでなく、平年値も取得して2列並べて出力することにします。
#１列のデータMshNと、1列のデータMshとを横結合して2列のデータにするには、下の一文を実行します。
ただし、この文をエラーなく実行するには、プログラムの最初にインポート文を書いてnumpyモジュールを
インポートしておかかくてはなりません。
import numpy as np
"""
Tateno = np.array([MshN,Msh])

AMD.PutCSV_TS(Tateno, tim, header="日付,平年値,観測値", filename="result2.csv")
"""
上の文を実行するとresult2.csvというファイルが作成され、下のような内容が書き込まれます。
----------------------
日付,平年値,観測値
2016-04-01 0:00,9.60319,11.76
2016-04-02 0:00,9.84214,10.4662
2016-04-03 0:00,10.0856,13.4721
2016-04-04 0:00,10.3276,14.3774
2016-04-05 0:00,10.5665,9.78284
2016-04-06 0:00,10.7986,12.6873
2016-04-07 0:00,11.0206,12.2915
2016-04-08 0:00,11.2314,13.3953
2016-04-09 0:00,11.4319,15.498
2016-04-10 0:00,11.6208,14.5004
2016-04-11 0:00,11.7975,10.7019
2016-04-12 0:00,11.9671,8.80379
2016-04-13 0:00,12.1331,14.2047
2016-04-14 0:00,12.2975,14.7056
----------------------
"""


