# -*- coding: utf-8 -*-
"""
　リスト(sample11_RiceDevelPoi_data.csv)に示された地点における出穂日の予測を行い、
前年の気象条件における推定出穂日との遅速とともにファイル(result.csv)に出力するプログ
ラム。このプログラムと共に提供されるサンプルデータは下の通りです。
－－－
ID,地区,地点名,緯度,経度,品種パラメータ1,品種パラメータ2,移植日
1,谷和原,A-3,35.69,139.76,10,950,2017/5/5
2,谷和原,A-4,36.38,140.4666667,10,950,2017/6/1
3,谷和原,A-5,36.54833333,139.8683333,10,950,2017/5/23
4,谷和原,A-6,36.405,139.06,10,950,2017/5/10
5,谷和原,A-7,36.15,139.38,10,950,2017/5/10
6,観音台,KR01,35.73833333,140.8566667,10,1000,2017/5/18
7,観音台,KR02,35.43833333,139.6516667,10,1000,2017/5/18
8,観音台,KR03a,35.66666667,138.5533333,10,1010,2017/5/26
9,観音台,KR03b,36.66166667,138.1916667,10,1010,2017/5/26
－－－
　このプログラムは、発育速度関数を自分では用意していません。
sample10_RiceDevel.pyで定義した関数をインポートして利用しています。

	OHNO, Hiroyuki 2012.08.29
"""
import AMD_Tools3 as AMD
from datetime import datetime, timedelta
from sample_RiceDevel import DVR	#他のプログラムで開発した関数を利用することができます。

# 地点リストの読み込み。
header, body = AMD.GetCSV_Table('sample_RiceDevelPoi-data.csv') 	#関数GetCSV_Tableは、すべての項目を文字列として読み込みます。
nore = len(body)	                                   #リストに掲載される地点数
sid = [body[oo][0] for oo in range(nore)]           #これがリスト内包表記です
slat = [float(body[oo][3]) for oo in range(nore)]
slon = [float(body[oo][4]) for oo in range(nore)]
DVIini = [float(body[oo][5]) for oo in range(nore)]
p1 = [float(body[oo][6]) for oo in range(nore)]
p2 = [float(body[oo][7]) for oo in range(nore)]
dtp = [datetime.strptime(body[oo][8], '%Y/%m/%d') for oo in range(nore)]

dem = []   #今年の出穂日の日付の要素番号(何個目の日付か)のためのリ空のリスト
deml = []   #前年の出穂日の日付の要素番号(何個目の日付か)のためのリ空のリスト
for s in range(nore): 
    print(sid[s])
    para = [p1[s],p2[s]]    #発育速度関数に与える品種パラメータ
    #前年の出穂日の計算
    tbeg = datetime(dtp[s].year-1, dtp[s].month, dtp[s].day)     #丁度1年前の同じ日の時刻オブジェクト
    tend = tbeg + timedelta(days=90)       #その日から90日の時刻オブジェクト
    timedomain = [tbeg.strftime('%Y-%m-%d'),tend.strftime('%Y-%m-%d')]
    lalodomain = [slat[s],slat[s],slon[s],slon[s]]
    Ta,tim,lat,lon = AMD.GetMetData('TMP_mea', timedomain,lalodomain)
    Ta = Ta[:,0,0]
    noda = len(tim)
    DVI = DVIini[s]
    for d in range(noda):
        DVI = DVI + DVR(Ta[d],Para=para)   #DVRの積算
        if DVI > 1.0 : 
            deml.append(d)  #出穂日(要素番号)の記録
            break
    #今年の出穂日の計算
    tbeg = dtp[s]
    tend = tbeg + timedelta(days=90)       #その日から90日の時刻オブジェクト
    timedomain = [tbeg.strftime('%Y-%m-%d'),tend.strftime('%Y-%m-%d')]
    lalodomain = [slat[s],slat[s],slon[s],slon[s]]
    Ta,tim,lat,lon = AMD.GetMetData('TMP_mea', timedomain,lalodomain)
    Ta = Ta[:,0,0]
    noda = len(tim)
    DVI = DVIini[s]
    for d in range(noda):
        DVI = DVI + DVR(Ta[d],Para=para)   #DVRの積算
        if DVI > 1.0 : 
            dem.append(d)  #出穂日(要素番号)の記録
            break
diff = [dem[oo]-deml[oo] for oo in range(nore)]   #前年に対する推定日との遅速を計算を全地点について行いリストにする。

with open('result.csv', 'wt') as f:   #結果書き出しのためにファイルをオープン
    f.write(header[0]+','+'"予測出穂日('+datetime.today().strftime('%m/%d')
                                    +'現在）","去年との遅速(日)"\n')   #見出し行の出力
    for s in range(nore):            
        f.write(sid[s]+','+tim[dem[s]].strftime('%Y/%m/%d')+','+str(diff[s]) +'\n')   #予測出穂日の出力
