# -*- coding: utf-8 -*-
"""
　DayLength3モジュールが提供する機能の利用法を理解するためのサンプルプログラム

　このサンプルプログラムでは、まず、daylength関数を利用して、茨城県における2017年6月21日の日長
時間の分布図を作成します。次に、茨城県つくば市館野(N36.0566,E140.125)における2017年の日長
時間の年変化グラフを作成します。

　このサンプルプログラムを実行するには、Python統合開発環境Spyderのエディタペインにプログラムファイル
 を読み込んでから実行ボタン(三角ボタン）をクリックしてください。

Hiroyuki OHNO, 2017.06.02
"""

import AMD_Tools3 as AMD
from DayLength3 import daylength
import numpy as np
import matplotlib.pylab as plt
import matplotlib.dates as md
from datetime import datetime, timedelta


# －－茨城県における2017年6月21日の日長時間の分布図の作成－－
element = 'pref_0800' #地理情報の指定、茨城県の県域
lalodomain = [ 35.733, 36.950, 139.690, 140.860]  #茨城県が収まる領域
Pref,lat,lon = AMD.GetGeoData(element,lalodomain)

tim = [datetime(2017,6,21)]
ld = daylength(tim,lat,lon)
ld = ld[0,:,:]  #3次元の入れも物で返された結果を2次元の入れ物に入れ替える

D2D = ld * Pref  #分布図はD2Dという名の変数に入れてください。
tate = 6         #図を入れるオブジェクト(入れ物)の全体的な大きさを指定します。
figtitle = "Day length over Ibaraki Pref. on "+tim[0].strftime('%Y-%m-%d')         
manualscl = True    #カラースケールの上限値と下限値を指定したいときに使用します。
sclmax  = 14.75              #最大値
sclmin  = 14.55              #最小値
sclint  = 0.005              #色の刻み
if not manualscl :
    sclmax = round(np.nanmax(np.array(D2D)),1)
    sclmin = round(np.nanmin(np.array(D2D)),1)
    sclint = round(((sclmax-sclmin)/10.0),1)
levels = np.arange(sclmin, sclmax+sclint, sclint)
yoko = tate * (np.max(lon)-np.min(lon))/(np.max(lat)-np.min(lat)) + 2
fig = plt.figure(num=None, figsize=(yoko, tate))#図を入れるオブジェクト(入れ物)を定義
plt.axes(axisbg='0.8')    #背景を灰色に
#plt.axes(facecolor='0.8')    #背景を灰色に  警告が表示される場合は上の行の代わりにこちらを使ってください。
levels = np.arange(sclmin, sclmax+sclint, sclint)
cmap = plt.cm.Spectral_r    #色調(カラーマップ)を愛称(「_r」を最後に付けると反転する)で指定
cmap.set_over('w', 1.0)
cmap.set_under('k', 1.0)
CF = plt.contourf(lon, lat, D2D, levels, cmap=cmap, extend='both')
plt.colorbar(CF)
plt.title(figtitle)
# 画像ファイル： 下の文のコメントアウトを解くと図をファイルに保存できます。
# plt.savefig('result'+'.png', dpi=600)
plt.show()
plt.clf()


# －－茨城県つくば市館野における2017年の日長時間の年変化グラフ－－
lat = 36.0566   #茨城県つくば市舘野の緯度
lon = 140.125   #茨城県つくば市舘野の経度

# 日付のリストの作成
tim = [datetime(2017,1,1)+timedelta(days=oo) for oo in range(365)]  #2017年1月1日から12月31日までの日付オブジェクトのリストを作成
ld = daylength(tim,[lat],[lon]) #daylength関数には日付、緯度、経度を配列で与えなければならないので、lat,lonを[]で囲み1要素の配列の体裁をとる。
ld = ld[:,0,0] #daylength関数は結果を3次元の入れ物(配列)で返すので、これを1次元の入れ物に入れなおす。

#折れ線グラフの作成
figtitle = 'N'+str(lat)+', E'+str(lon)         
fig = plt.figure(num=None, figsize=(12, 4))
# 目盛
ax = plt.axes()
xmajoPos = md.DayLocator(bymonthday=[1])
xmajoFmt = md.DateFormatter('%m/%d')
ax.xaxis.set_major_locator(xmajoPos)
ax.xaxis.set_major_formatter(xmajoFmt)
xminoPos = md.DayLocator()
ax.xaxis.set_minor_locator(xminoPos)
# 折れ線
ax.plot(tim, ld, 'r')
# ラベル、タイトル
plt.xlabel('Date')
plt.ylabel('Day Length [hours]')
plt.title(figtitle)
# 画像ファイル： 下の文のコメントアウトを解くと図をファイルに保存できます。
# plt.savefig('result'+'.png', dpi=600)
# 表示
plt.show()
plt.clf()
  